# Release information about Select-Shuttle

version = "0.92"

description = """The SelectShuttle widget provides a mechanism for selecting
multiple values from a list of values by allowing the user to move items
between two lists. On modern browsers you can also double click an item to
move it from one list to the other. After the first "move", all entries
will be sorted automatically accordingly to its "description" on both
lists. Take a look at the code for SelectShuttleDesc for an example of how
to use this widget in your code."""

author = "Jorge Godoy"

email = "jgodoy@gmail.com"

url = "http://www.g2ctech.com/"
download_url = "http://www.g2ctech.com/widgets/Select_Shuttle-%s-py2.4.egg" % version
license = "MIT"
